Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2013-11-03 23:35:59 +0000
committerStijn Buys <ingar@osirion.org>2013-11-03 23:35:59 +0000
commit8126e1941666f5dccd61e9ecc60db162049bb8ff (patch)
tree9468363f1670352ec8d5f2155cfcfa77b602d772 /src/game/base/jumppoint.h
parentfb18eff66171e855e378575b534683e4fb9c20f5 (diff)
Added initial support for NPC patrol routes,
added support for lawfull/unlawfull factions.
Diffstat (limited to 'src/game/base/jumppoint.h')
-rw-r--r--src/game/base/jumppoint.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/game/base/jumppoint.h b/src/game/base/jumppoint.h
index 33a9f9f..655d133 100644
--- a/src/game/base/jumppoint.h
+++ b/src/game/base/jumppoint.h
@@ -31,8 +31,8 @@ public:
JumpPoint();
virtual ~JumpPoint();
- inline std::string const & targetlabel() {
- return jumppoint_targetlabel;
+ inline std::string const & target_label() {
+ return jumppoint_target_label;
}
inline JumpPoint *target() {
@@ -40,9 +40,9 @@ public:
}
/// set trget label
- void set_targetlabel(const std::string &label);
+ void set_target_label(const std::string &label);
- /// validate the targetlabel and set target()
+ /// validate the target_label and set target()
virtual void validate();
static inline void set_template (const Template *entitytemplate) {
@@ -50,7 +50,7 @@ public:
}
private:
- std::string jumppoint_targetlabel;
+ std::string jumppoint_target_label;
JumpPoint *jumppoint_target;
static const Template *jumppoint_template;
@@ -63,7 +63,7 @@ public:
JumpGate();
virtual ~JumpGate();
/// validate the targetlabel and set target()
virtual void validate();
/// a ship wants to use the jumpgate
@@ -63,7 +63,7 @@ public:
JumpGate();
virtual ~JumpGate();
- /// validate the targetlabel and set target()
+ /// validate the target_label and set target()
virtual void validate();
/// a ship wants to use the jumpgate